% script membrane
% movement of a membrane in a given flow field
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc; clear all; close all;

n = 31;
markers = 50; % number of marker points of the membrane
x = linspace(0,1,n)';
y = linspace(0,1,n)';

h = x(2)-x(1);

[X,Y] = ndgrid(x,y);

% velocity of the flow:

u = load('rotate_U.dat');
v = load('rotate_V.dat');

% visualise the velocity
figure(1)
quiver(X,Y,u,v);
hold on
axis equal;

% initialise the membrane

% ellipse
xc = 0.5; yc = 0.3;
r = 0.05;
phi = linspace(0,2*pi,markers)';
x_m = xc+r*cos(phi);
y_m = yc+2*r*sin(phi);

% visualise the initial configuration
plot(x_m,y_m,'r');


tau = h;
Tsteps = 50; % number of time steps to be done

% compute the coefficients of cubic splines
[Ucfs,Vcfs] = spline_cfs(x,y,h,u,v);

for i = 1:Tsteps
  % interpolate the velocity field to the 
  % marker points of the membrane
  
  % evaluate the values at the points (x_m,y_m)

  [P_U,P_V] = evaluate_interpolant(x_m,y_m,Ucfs,Vcfs,x,y,n,h);  
  
  % update the membrane coordinates
  x_m = x_m + tau*P_U;
  y_m = y_m + tau*P_V;

  clf;
  quiver(X,Y,u,v);
  hold on
  axis equal;
  plot(x_m,y_m,'r');
  axis([0 1 0 1]);
  drawnow
end
